"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var node_hid_1 = require("node-hid");
var HidUsbDevice = /** @class */ (function () {
    function HidUsbDevice(rawDevice, vendorId, productId) {
        this.rawDevice = rawDevice;
        this.vendorId = vendorId || rawDevice.vendorId;
        this.productId = productId || rawDevice.productId;
    }
    HidUsbDevice.prototype.fetchInfo = function (writeBytes) {
        var report = [];
        try {
            this.connectToHID();
            this.write(writeBytes);
            report = this.readSync();
        }
        finally {
            this.close();
        }
        return report;
    };
    HidUsbDevice.prototype.realDevice = function () {
        return this.rawDevice;
    };
    HidUsbDevice.prototype.path = function () {
        return this.rawDevice.path;
    };
    // There's two ways you can have a HID connection.
    //  1. From the `HID.devices()` method with everything auto filled in or
    //  2. We need to make a connection from the `vendorId` and `productId`
    //
    // This logic ensures we have an useable HID connection
    HidUsbDevice.prototype.connectToHID = function () {
        if (this.rawDevice !== undefined && this.rawDevice.path) {
            this.hidDevice = new node_hid_1.HID(this.rawDevice.path);
        }
        else if (this.vendorId !== undefined && this.vendorId !== 0) {
            try {
                this.hidDevice = this.createNewHIDByVendorIdAndProductId();
            }
            catch (e) {
                // This happens if the device (USB Dongle) has been removed
                // console.debug(e);
            }
        }
    };
    HidUsbDevice.prototype.readSync = function () {
        if (this.hidDevice) {
            return this.hidDevice.readTimeout(100);
        }
        return [];
    };
    HidUsbDevice.prototype.write = function (bytes) {
        if (this.hidDevice) {
            this.hidDevice.write(bytes);
        }
    };
    HidUsbDevice.prototype.close = function () {
        if (this.hidDevice) {
            this.hidDevice.close();
        }
    };
    HidUsbDevice.prototype.createNewHIDByVendorIdAndProductId = function () {
        return new node_hid_1.HID(this.vendorId, this.productId);
    };
    return HidUsbDevice;
}());
exports.default = HidUsbDevice;
