#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var node_hid_1 = __importDefault(require("node-hid"));
var readline = __importStar(require("readline"));
var gateway_1 = __importDefault(require("../adapters/human_interface_device/gateway"));
var device_1 = __importDefault(require("../adapters/human_interface_device/device"));
var known_headphone_1 = __importDefault(require("../models/known_headphone"));
function testUnknownHeadset(headsets) {
    return headsets.map(function (device) {
        var knownBytes = [
            [0x06, 0x18],
            [0x06, 0x12],
        ];
        var matchedReport, matchedBytes;
        console.log('Testing', device.realDevice().product);
        knownBytes.some(function (byteArray) {
            var report = device.fetchInfo(byteArray);
            if (report.length > 0) {
                matchedBytes = byteArray;
                matchedReport = report;
                console.log('\tSuccess!');
                return true;
            }
        });
        return {
            device: device,
            matchedBytes: matchedBytes,
            matchedReport: matchedReport,
        };
    });
}
function printPreamble() {
    console.log('Welcome to Arctis USB Finder Probe');
    console.log(' ');
    console.log('This tool will probe USB devices that look like they are SteelSeries USB devices.');
    console.log('**** It will write/send a command to the USB device. ****');
    console.log('**** It may have side effects / potentially (worst case) brick your device. ****');
    console.log('');
}
function exitMessage() {
    console.log('Exiting...');
    process.exit(0);
}
function probe() {
    console.log(' ');
    console.log('About to look for SteelSeries USB devices...');
    console.log(' ');
    var gateway = new gateway_1.default(node_hid_1.default, device_1.default);
    var devices = gateway.getUsbDevices();
    var steelseriesHeadsets = devices.filter(function (device) {
        return device.vendorId === known_headphone_1.default.ArctisVendorID;
    });
    if (steelseriesHeadsets.length < 0) {
        console.log("Didn't find any SteelSeries Headset");
        exitMessage();
    }
    console.log(' ');
    console.log('Found SteelSeries USB devices:');
    console.log(' ');
    steelseriesHeadsets.forEach(function (device) { return console.log(device.realDevice().product); });
    console.log(' ');
    console.log(' ');
    console.log('About to Probe...');
    console.log(' ');
    var foundHeadphones = testUnknownHeadset(steelseriesHeadsets);
    console.log(' ');
    console.log('**** Finished Probing ****');
    console.log(' ');
    console.log(' ');
    if (foundHeadphones.length > 0) {
        console.log('Use can use the following information to create a develop your own solution and create a PR.');
        console.log('Or please copy / paste the following information and create an issue on the GitHub repo.');
        console.log('Go to: https://github.com/richrace/arctis-usb-finder/');
        console.log('You can look for values changing when press mute/changing chat mixer/charging');
        console.log(' ');
        console.log(' ');
        console.log('Devices found:');
        console.log(' ');
        foundHeadphones.forEach(function (result) {
            console.log('Product:', result.device.realDevice().product);
            console.log('Product ID:', result.device.productId);
            console.log('Bytes:', result.matchedBytes);
            console.log('Report:', result.matchedReport);
            console.log('Path:', result.device.path());
            console.log(' ');
        });
    }
    exitMessage();
}
var rl = readline.createInterface({
    input: process.stdin,
    output: process.stdout,
});
printPreamble();
rl.question('Do you understand the risks and are happy to proceed? (Y/n): ', function (answer) {
    var agreeToContinue = answer.replace(/ /g, '').toLowerCase();
    if (['y', 'yes', 'continue'].indexOf(agreeToContinue) === -1) {
        console.log(' ');
        console.log('Aborting...');
        process.exit(1);
    }
    rl.close();
    probe();
});
